@@ -3,10 +3,8 @@ import logging
 import os
 from datetime import datetime, timedelta
 
-from notecoin.base.database.lanzou import LanzouDirectory
+from notecoin.base.drive.lanzou import LanzouDirectory
 from notecoin.coins.base.load import LoadDataKline, LoadTradeKline
-from notecoin.utils.time import (day_during, month_during, week_during,
-                                 year_during)
 from notefile.compress import tarfile
 from tqdm import tqdm
 
@@ -167,33 +165,3 @@ class DataFileProperty:
     def load_merge(self, start_time, end_time):
         self.file_pro.start_date, self.file_pro.end_date = start_time, end_time
         self._merge_and_save(self.file_pro)
-        
-    def _load(self, start_end_fun, total=100):
-        for i in range(1, total):
-            try:
-                self.file_pro.start_date, self.file_pro.end_date = start_end_fun(-i)
-                self._daily_load_and_save(self.file_pro)
-            except Exception as e:
-                print(e)
-
-    def _merge(self, start_end_fun, total=10):
-        for i in range(total, 0, -1):
-            try:
-                self.file_pro.start_date, self.file_pro.end_date = start_end_fun(-i)
-                self._merge_and_save(self.file_pro)
-            except Exception as e:
-                print(e)
-
-    def load(self, total=100):
-        if self.file_pro.freq == 'daily':
-            self.file_format = '%Y%m%d'
-            self._load(day_during, total)
-        elif self.file_pro.freq == 'weekly':
-            self.file_format = '%Y%m%d'
-            self._merge(week_during, total)
-        elif self.file_pro.freq == 'monthly':
-            self.file_format = '%Y%m'
-            self._merge(month_during, total)
-        elif self.file_pro.freq == 'yearly':
-            self.file_format = '%Y'
-            self._merge(year_during, total)
