@@ -80,10 +80,8 @@ class StrategyTask(BaseTask):
 
         sell_json = self.exchange.create_order(symbol, 'market', 'sell', amount)
         value = {
-            "id": 1,
+            "id": id,
             "sell_json": sell_json,
         }
 
         self.table.upsert(values=[value])
-
-
